@@ -1,5 +1,6 @@
 function FileManager(rest_interface) {
     var files = {},
+        is_breakable = {},
         programListingTemplate = Handlebars.compile( $('#program-listing-template').html() ),
         array_or_hash_element_or_slice = /^(([$@])(\w+(::\w+)*)([[{]))/,
         scalar_array_hash_or_glob = /^(([$@%*])(\w+(::\w+)*))/,
@@ -75,12 +76,14 @@ function FileManager(rest_interface) {
         if (source_lines) {
             // File is loaded
             templateData = { filename: filename, rows: [] };
+            is_breakable[filename] = {};
             for (i = 0; i < source_lines.length; i++) {
                 templateData.rows.push({
                         line: i+1,
                         code: Handlebars.Utils.escapeExpression(source_lines[i][0]),  // This gets re-htmlified below in codeElt.html()
                         unbreakable: !source_lines[i][1]
                 });
+                is_breakable[filename][i+1] = (source_lines[i][1] ? true : false);
             }
             var $elt = $( programListingTemplate(templateData) );
             $elt.find('.code').each(function(idx,codeElt) {
@@ -106,4 +109,11 @@ function FileManager(rest_interface) {
         }
         return files[filename].promise()
     };
+
+    this.isLoaded = function(filename) {
+         return ((filename in files) && files[filename]);
+    };
+    this.isBreakable = function(filename, line) {
+        return is_breakable[filename][line];
+    };
 }
