@@ -67,7 +67,11 @@ sub start_test_program {
     if ($module_args) {
         $module_invocation .= ",$module_args";
     }
+
+    my $other_includes = $ENV{HDB_TEST_INCLUDE} || '';
+
     my $cmdline = join(' ', $^X, "-I $libdir $module_invocation",
+                               $other_includes,
                                $program_file,
                                @argv);
 
@@ -81,18 +85,7 @@ sub start_test_program {
         die "fork failed: $!";
     }
 
-    local $@;
-    eval qq(END {
-        print STDERR "# >>> Killing pid $pid\\n";
-        my \$killed = kill('TERM',$pid);
-        print STDERR "# >>> kill returned \$killed\\n";
-        local \$?;
-        my \$killed_pid = waitpid($pid, 0);
-        my \$exit_code = \$? >> 8;
-        my \$signal = \$? & 127;
-        my \$coredump = \$? & 128;
-        print STDERR "# >>> killed pid was \$killed_pid, \\\$?: \$?, exit code \$exit_code, signal \$signal, core \$coredump\\n";
-    });
+    eval "END { Test::More::note('Killing pid $pid'); kill 'TERM',$pid }";
     $HdbHelper::child_pid = $pid;
 
     if (wantarray) {
